@@ -5,6 +5,7 @@ import com.facebook.react.bridge.JavaScriptModule;
 import com.facebook.react.bridge.NativeModule;
 import com.facebook.react.bridge.ReactApplicationContext;
 import com.facebook.react.uimanager.ViewManager;
+import com.google.android.gms.tagmanager.ContainerHolder;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Collections;
@@ -12,14 +13,20 @@ import java.util.List;
 
 public class GoogleAnalyticsBridgePackage implements ReactPackage {
 
-    public GoogleAnalyticsBridgePackage(String trackingId) {
+    public GoogleAnalyticsBridgePackage(ContainerHolder containerHolder, String trackingId) {
+        _containerHolder = containerHolder;
         _trackingId = trackingId;
     }
 
-    public GoogleAnalyticsBridgePackage() {
-        this(null);
+    public GoogleAnalyticsBridgePackage(String trackingId) {
+        this(null, trackingId);
     }
 
+    public GoogleAnalyticsBridgePackage() {
+        this(null, null);
+    }
+
+    private ContainerHolder _containerHolder = null;
     private String _trackingId;
 
     @Override
@@ -28,11 +35,16 @@ public class GoogleAnalyticsBridgePackage implements ReactPackage {
         List<NativeModule> modules = new ArrayList<>();
 
         modules.add(new GoogleAnalyticsBridge(reactContext, _trackingId));
-        modules.add(new GoogleTagManagerBridge(reactContext));
-        
+        modules.add(new GoogleTagManagerBridge(reactContext, _containerHolder));
+
         return modules;
     }
 
+    // Deprecated from RN 0.47.0
+    public List<Class<? extends JavaScriptModule>> createJSModules() {
+        return Collections.emptyList();
+    }
+
     @Override
     public List<ViewManager> createViewManagers(ReactApplicationContext reactContext) {
         return Arrays.<ViewManager>asList();
